==> xcsoar-6.8.4.tar.xz: xcsoar-6.8.4/src/Waypoint/SaveGlue.cpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2015 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#include "WaypointGlue.hpp"
#include "CupWriter.hpp"
#include "LogFile.hpp"
#include "IO/TextWriter.hpp"
#include "LocalPath.hpp"

#include <windef.h> /* for MAX_PATH */

bool
WaypointGlue::SaveWaypoints(const Waypoints &way_points)
{
  TCHAR path[MAX_PATH];
  LocalPath(path, _T("user.cup"));

  TextWriter writer(path);
  if (!writer.IsOpen()) {
    LogFormat(_T("Waypoint file '%s' can not be written"), path);
    return false;
  }

  WriteCup(writer, way_points, WaypointOrigin::USER);

  LogFormat(_T("Waypoint file '%s' saved"), path);
  return true;
}

bool
WaypointGlue::SaveWaypoint(const Waypoint &wp)
{
  TCHAR path[MAX_PATH];
  LocalPath(path, _T("user.cup"));

  TextWriter writer(path, true);
  if (!writer.IsOpen()) {
    LogFormat(_T("Waypoint file '%s' can not be written"), path);
    return false;
  }

  WriteCup(writer, wp);
  return true;
}

==> xcsoar-6.8.17.tar.xz: xcsoar-6.8.17/src/Waypoint/SaveGlue.cpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2015 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#include "WaypointGlue.hpp"
#include "CupWriter.hpp"
#include "LogFile.hpp"
#include "IO/TextWriter.hpp"
#include "LocalPath.hpp"

#include <windef.h> /* for MAX_PATH */

bool
WaypointGlue::SaveWaypoints(const Waypoints &way_points)
{
  TCHAR buffer[MAX_PATH];
  const auto path = LocalPath(buffer, _T("user.cup"));

  TextWriter writer(path);
  if (!writer.IsOpen()) {
    LogFormat(_T("Waypoint file '%s' can not be written"), path);
    return false;
  }

  WriteCup(writer, way_points, WaypointOrigin::USER);

  LogFormat(_T("Waypoint file '%s' saved"), path);
  return true;
}

bool
WaypointGlue::SaveWaypoint(const Waypoint &wp)
{
  TCHAR buffer[MAX_PATH];
  const auto path = LocalPath(buffer, _T("user.cup"));

  TextWriter writer(path, true);
  if (!writer.IsOpen()) {
    LogFormat(_T("Waypoint file '%s' can not be written"), path);
    return false;
  }

  WriteCup(writer, wp);
  return true;
}
